# alpha-eigen
Using dynamic mode decomposition to calculate alpha-eigenvalues for time-dependent radiation transport problems.

## Install




These codes are intended to continue work from the paper McClarren, R. G. (2019). Calculating Time Eigenvalues of the Neutron Transport Equation with Dynamic Mode Decomposition. Nuclear Science and Engineering, 193(8), 854–867. http://doi.org/10.1080/00295639.2018.1565014
